<?php
namespace Ep\Woo\Form\View\Element;

use Ep\Woo\Product\ProductInterface;
use Ep\Woo\View\AbstractView;

/**
 * Class Quantity
 *
 * @package Ep\Woo\Form\View\Element
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-woocommerce
 */
class Quantity extends AbstractView
{
    /** @var array */
    protected $templateOverrides = [
        'global/quantity-input.php',
    ];

    /**
     * Inicijalizacija.
     */
    public function init(): void
    {
        parent::init();

        add_filter('woocommerce_cart_item_quantity', [$this, 'renderInCart'], 10, 3);
    }

    /**
     * Renderira view.
     *
     * @return string
     */
    public function render(): string
    {
        global $product;

        $args = func_get_args()[3];

        $element = new \Ep\Woo\Form\Element\Quantity($args['input_name'], [
            'label' => __('Quantity', 'woocommerce'),
        ]);

        $element->init();

        $element->setAttributes([
            'id' => $args['input_id'],
            'value' => $args['input_value'],
            'min' => $args['min_value'],
            'max' => $args['max_value'],
            'step' => $args['step'],
            'pattern' => $args['pattern'],
            'inputmode' => 'numeric',
        ]);

        $helper = $this->helpers->get('form_quantity');

        return $helper($element);
    }

    public function renderInCart($product_quantity, $cart_item_key, $cart_item)
    {
        /** @var ProductInterface $product */
        $product = wc_get_product($cart_item['product_id']);

        $element = new \Ep\Woo\Form\Element\Quantity(sprintf('cart[%s][qty]', $cart_item_key), [
            'label' => __('Quantity', 'woocommerce'),
        ]);

        $element->init();

        $element->setAttributes([
            'value' => $cart_item['quantity'],
            'min' => 0,
            'max' => $product->getMaxPurchaseQuantity(),
            'step' => $product->getPurchaseStep(),
        ]);

        $helper = $this->helpers->get('form_quantity');
        return $helper($element);
    }
}